@@ -3,16 +3,16 @@
  * Copyright © 2007  Christian Persch
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
+ * modify it under the terms of the GNU General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * version 3 of the License, or (at your option) any later version.
  *
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
+ * General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
+ * You should have received a copy of the GNU General Public
  * License along with this library; if not, write to the
  * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
  * Boston, MA 02110-1301, USA.
@@ -173,7 +173,7 @@ gucharmap_chartable_cell_accessible_action_do_action (AtkAction *action,
 }
 
 
-static G_CONST_RETURN gchar*
+static const gchar*
 gucharmap_chartable_cell_accessible_action_get_name (AtkAction *action,
                           gint      index)
 {
@@ -184,7 +184,7 @@ gucharmap_chartable_cell_accessible_action_get_name (AtkAction *action,
 }
 
 
-static G_CONST_RETURN gchar *
+static const gchar *
 gucharmap_chartable_cell_accessible_action_get_description (AtkAction *action,
                                  gint      index)
 {
